# talonfmt

![GitHub Workflow Status](https://github.com/wenkokke/talonfmt/actions/workflows/build.yml/badge.svg) ![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/wenkokke/talonfmt) ![PyPI](https://img.shields.io/pypi/v/talonfmt)

Code formatter for Talon files.
